# please before bumping the version of this package ensure there is a
# match between the openshadinglanguage version used in the blender
# package and in the upstream blender (the easiest way to check is to
# take just the upstream blender binaries at the same version level of
# our blender. run them and do a save system-info.txt from the Edit
# menu, so to get the list of library versions actually used); if a
# newer OSL package is needed, fork this package using something like:
#
# svn cp svn+ssh://svn.mageia.org/svn/packages/cauldron/openshadinglanguage1.11 \
#         svn+ssh://svn.mageia.org/svn/packages/cauldron/openshadinglanguage1.13
#
# (e.g. for forking from release 1.11 to 1.13). Then in the new
# package, fix the %%libmajor, %%apiversion and the newer name of the
# SPEC file accordingly.

%define fver		%{version}
%define libmajor	1.13
%define apiversion	1.13
%define pkgname		openshadinglanguage

%define libname		%mklibname %{pkgname} %{libmajor}
%define develname	%mklibname %{pkgname} %{apiversion} -d

%define optflags_lto %nil

Name:		openshadinglanguage%{libmajor}
Version:	1.13.12.0
Release:	%mkrel 1
Summary:	A language for programmable shading in advanced renderers
Group:		Graphics/3D
License:	BSD-3-Clause
Url:		https://github.com/AcademySoftwareFoundation/OpenShadingLanguage
Source0:	https://github.com/AcademySoftwareFoundation/OpenShadingLanguage/archive/v%{fver}/OpenShadingLanguage-%{version}.tar.gz
# Upstream patches
#
# Mageia patches
Patch101:	osl-gcc15.patch
Patch102:	osl-llvm20.patch

#
# 64 bit only
ExcludeArch:	%{ix86} %{arm32}

BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	cmake(pybind11)
BuildRequires:	clang
BuildRequires:	clang-devel
BuildRequires:	flex
BuildRequires:	llvm-devel
BuildRequires:	boost-devel
BuildRequires:	ninja
BuildRequires:	openimageio
%ifnarch %{ix86} %{arm32}
BuildRequires:	partio-devel
%endif
%if %mgaversion < 9
BuildRequires:	pkgconfig(IlmBase)
%else
BuildRequires:	pkgconfig(Imath)
%endif
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(OpenImageIO) >= 2.0
BuildRequires:	pkgconfig(pugixml)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(numpy)
BuildRequires:	cmake(Qt6)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6OpenGLWidgets)
BuildRequires:	cmake(Qt6Widgets)

%description
Open Shading Language (OSL) is a small but rich language for
programmable shading in advanced renderers and other applications,
ideal for describing materials, lights, displacement, and pattern
generation.

%package -n %{libname}
Summary:	A language for programmable shading in advanced renderers
Group:		System/Libraries
Provides:	openshadinglanguage = %{version}-%{release}
Provides:	%{pkgname} = %{version}-%{release}
Provides:	lib%{pkgname} = %{version}-%{release}
Provides:	lib%{name} = %{version}-%{release}
Obsoletes:	%{_lib}openshadinglanguage1.13_1.13 < 1.13.12.0


%description -n %{libname}
Open Shading Language (OSL) is a small but rich language for
programmable shading in advanced renderers and other applications,
ideal for describing materials, lights, displacement, and pattern
generation.

This package contains the shared library of OpenShadingLanguage.

%package -n %{develname}
Summary:	Development files for the OpenShadingLanguage library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{pkgname}-devel = %{version}-%{release}
Provides:	lib%{pkgname}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for the OpenShadingLanguage library.

Install this package if you want to compile applications using the
OpenShadingLanguage library.

%package -n python3-%{name}
Summary:	Python files for the OpenShadingLanguage library
Group:		Development/Python	
Requires:	%{libname} = %{version}-%{release}
	
%description    -n python3-%{name}
Python bindinds for the OpenShadingLanguage.

%package -n openimageio-plugin-osl
Summary:	OSL plugin for OpenImageIO
Group:		Graphics/3D

%description -n openimageio-plugin-osl
OSL plugin for OpenImageIO.

%prep
%autosetup -p1 -n OpenShadingLanguage-%{fver}

%py3_shebang_fix src/build-scripts/serialize-bc.py

%build
# TODO: rebuild without -DSTOP_ON_WARNING:BOOL=OFF

# Note for packagers: the OpenImageIO plugin search path is defined with the
# configuration option "-DPLUGIN_SEARCH_PATH" in the openimageio.spec
# file. Please ensure that the file "osl.imageio.so" is placed at the
# right place to match the path defined in the openimageio package
# (which is %{_libdir} for now). Please do not move the plugin file manually in other places,
# unless fixing the path in the openimageio.spec file accordingly.
%cmake	-GNinja \
	-DVERBOSE:BOOL=ON \
	-DCMAKE_CXX_STANDARD=17 \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DOSL_SHADER_INSTALL_DIR:PATH=%{_datadir}/%{name} \
%ifarch %{arm32}
	-DOSL_OIIO_NO_NEON:BOOL=ON \
%endif
%ifarch %{ix86} %{arm32}
	-DUSE_PARTIO:BOOL=OFF \
%endif
	-DSTOP_ON_WARNING:BOOL=OFF
# avoid build break in simd which includes NEON armv8 instruction

%cmake_build


%install
%cmake_install
#
rm -f %{buildroot}%{_usr}/cmake/llvm_macros.cmake \
	%{buildroot}%{_usr}/build-scripts/serialize-bc.py

%files
%doc CHANGES.md CONTRIBUTING.md README.md
%license LICENSE.md
%{_bindir}/*
%{_datadir}/doc/OSL/*
%{_datadir}/%{name}

%files -n %{libname}
%{_libdir}/*.%{libmajor}{,.*}

%files -n %{develname}
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/cmake/OSL
%{_libdir}/pkgconfig/*.pc

%files -n python3-%{name}
%{python3_sitearch}/oslquery.so

%files -n openimageio-plugin-osl
%{_libdir}/osl.imageio.so


%changelog
* Thu May 01 2025 wally <wally> 1.13.12.0-1.mga10
+ Revision: 2180319
- new version 1.13.12.0
- fix lib pkg name
- rebuild for llvm 20.1.3

* Tue Mar 04 2025 daviddavid <daviddavid> 1.13.11.0-3.mga10
+ Revision: 2160310
- rebuild for python 3.13

* Sun Feb 09 2025 wally <wally> 1.13.11.0-2.mga10
+ Revision: 2146259
- rebuild for boost 1.87.0

* Mon Nov 25 2024 daviddavid <daviddavid> 1.13.11.0-1.mga10
+ Revision: 2118938
- new version: 1.13.11.0
- backport upstream patch add support for LLVM 19
+ wally <wally>
- rebuild for LLVM 19.1.3

* Fri Sep 13 2024 wally <wally> 1.13.8.0-3.mga10
+ Revision: 2095503
- rebuild for boost 1.86.0

* Wed Jun 19 2024 wally <wally> 1.13.8.0-2.mga10
+ Revision: 2075379
- rebuild for boost 1.85.0

* Tue Apr 02 2024 ghibo <ghibo> 1.13.8.0-1.mga10
+ Revision: 2053768
- Update to version 1.13.8.0
- Update to version 1.13.7.0
- Update to version 1.13.6.1
- Add beta1 name to release
- Update to version 1.13.6.0-beta1
- Update to release 1.13.0.2.
- Drop patch merged upstream.
- Rename SPEC file to openshadinglanguage1.13.spec
- Update to release 1.13.x for newer blender.

* Fri Jan 12 2024 wally <wally> 1.11.17.0-13.mga10
+ Revision: 2030579
- rebuild for boost 1.84.0

* Wed Dec 27 2023 daviddavid <daviddavid> 1.11.17.0-12.mga10
+ Revision: 2022184
- rebuild for py3.12

* Wed Sep 27 2023 wally <wally> 1.11.17.0-11.mga10
+ Revision: 1991481
- rebuild for boost 1.83.0
- build using cmake + ninja
+ ghibo <ghibo>
- Improve SPEC file suggestions

* Sun Jan 01 2023 wally <wally> 1.11.17.0-10.mga9
+ Revision: 1928614
- add patch to support building without ARM NEON support

* Sun Jan 01 2023 wally <wally> 1.11.17.0-9.mga9
+ Revision: 1928552
- another build for armv7 without NEON support

* Sun Jan 01 2023 wally <wally> 1.11.17.0-8.mga9
+ Revision: 1928531
- try harder to build without NEON support on armv7

* Sun Jan 01 2023 wally <wally> 1.11.17.0-7.mga9
+ Revision: 1928492
- rebuild for openimageio 2.4.6.1

* Sat Dec 24 2022 wally <wally> 1.11.17.0-6.mga9
+ Revision: 1926514
- rebuild for boost 1.81.0

* Sat Nov 05 2022 ghibo <ghibo> 1.11.17.0-5.mga9
+ Revision: 1903822
- Rebuild against newer openimageio

* Sat Oct 01 2022 papoteur <papoteur> 1.11.17.0-4.mga9
+ Revision: 1893602
- Fix again designation of armv7hl arch

* Sat Oct 01 2022 papoteur <papoteur> 1.11.17.0-3.mga9
+ Revision: 1893598
- Fix designation of armv7hl arch

* Fri Sep 30 2022 papoteur <papoteur> 1.11.17.0-2.mga9
+ Revision: 1893540
- Exclude partio also for armv7

* Fri Sep 30 2022 papoteur <papoteur> 1.11.17.0-1.mga9
+ Revision: 1893534
- Update to 1.11.17.0, thanks to ghibo
- Revert to the version 1.11
- Fork for the version 1.12
+ tv <tv>
- Rebuild for llvm-15
- Rebuild for llvm-14
+ wally <wally>
- rebuild for boost 1.79.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Mon Dec 27 2021 wally <wally> 1.10.13-11.mga9
+ Revision: 1764500
- add patch to fix build with openimageio 2.3
- rebuild for openexr 3.1.3

* Thu Dec 23 2021 wally <wally> 1.10.13-10.mga9
+ Revision: 1763494
- add patch to fix build with llvm13
- rebuild for boost 1.78.0
+ tv <tv>
- Rebuild for llvm 13.0

* Sat Sep 11 2021 wally <wally> 1.10.13-8.mga9
+ Revision: 1745175
- skip RPATH
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.10.13-7.mga9
+ Revision: 1723001
- rebuild for boost 1.76.0

* Mon Mar 01 2021 tv <tv> 1.10.13-6.mga9
+ Revision: 1695523
- rebuild for llvm/clang-12

* Thu Dec 31 2020 wally <wally> 1.10.13-5.mga8
+ Revision: 1666797
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.10.13-4.mga8
+ Revision: 1662039
- rebuild for boost 1.74.0

* Sat Dec 05 2020 ghibo <ghibo> 1.10.13-3.mga8
+ Revision: 1652992
- Add 2nd patch for building under llvm11
- Reorder patch numbering, closing holes.
- Add patch to fix building error about std::string.
+ tv <tv>
- rebuild for llvm/clang 11.0

* Sat Nov 07 2020 joequant <joequant> 1.10.13-1.mga8
+ Revision: 1643286
- update to latest point release 1.10.13

* Sat Nov 07 2020 joequant <joequant> 1.10.9-8.mga8
+ Revision: 1643249
- bump version
- disable simd neon only for arm32

* Sat Nov 07 2020 joequant <joequant> 1.10.9-7.mga8
+ Revision: 1643239
- disable unknown simd call for arm

* Fri Nov 06 2020 joequant <joequant> 1.10.9-6.mga8
+ Revision: 1643096
- bump up release for rebuild
- revert update to 1.11
- fix sources
- update to 1.11.8.0 and sync with fedora build
  Version 1.10 was not building because of obscure compile errors,
  and updating versions and porting patches did not work.

* Thu Nov 05 2020 joequant <joequant> 1.10.9-5.mga8
+ Revision: 1642845
- update build
+ daviddavid <daviddavid>
- rebuild for new openimageio 2.2.8.0

* Sat Sep 12 2020 daviddavid <daviddavid> 1.10.9-4.mga8
+ Revision: 1625303
- rebuild for new openexr/ilmbase 2.5.3

* Sun May 03 2020 wally <wally> 1.10.9-3.mga8
+ Revision: 1578093
- rebuild for boost 1.73.0

* Fri Apr 03 2020 daviddavid <daviddavid> 1.10.9-2.mga8
+ Revision: 1564141
- rebuild for new openimageio 2.1.13.0

* Thu Mar 26 2020 tv <tv> 1.10.9-1.mga8
+ Revision: 1560530
- new release
- rebuild for llvm-10.0.0

* Thu Feb 20 2020 umeabot <umeabot> 1.10.8-2.mga8
+ Revision: 1545098
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 daviddavid <daviddavid> 1.10.8-1.mga8
+ Revision: 1483769
- new version: 1.10.8
+ wally <wally>
- rebuild for boost 1.72.0
- build with new cmake macros

* Thu Oct 17 2019 daviddavid <daviddavid> 1.10.7-1.mga8
+ Revision: 1454221
- new version: 1.10.7 (LLVM 9 / clang 9 compatibility)
+ tv <tv>
- rebuild for llvm-9.0

* Mon Jul 15 2019 daviddavid <daviddavid> 1.10.5-2.mga8
+ Revision: 1421596
- rebuild for new openimageio 2.0.9

* Fri May 17 2019 ghibo <ghibo> 1.10.5-1.mga7
+ Revision: 1398164
- Update to release 1.10.5

* Fri Apr 26 2019 ghibo <ghibo> 1.10.4-3.mga7
+ Revision: 1395526
- Fix license

* Fri Apr 26 2019 ghibo <ghibo> 1.10.4-2.mga7
+ Revision: 1395482
- Added patches to fix lookup path for stdosl.h
- Fix URL

* Wed Apr 24 2019 ghibo <ghibo> 1.10.4-1.mga7
+ Revision: 1395059
- imported package openshadinglanguage1.10

